@@ -106,6 +106,9 @@ PPro@200MHz+WinNT+Obsidian (2 boards => 90 MPixels/sec):
   (v)[2]=clamp((v)[2]);\
 }
 
+#define WIDTH 640
+#define HEIGHT 480
+
 #define FRAME 50
 #define DIMP 20.0
 #define DIMTP 16.0
@@ -147,6 +150,8 @@ static float qt[4][2]={
   {-DIMTP,DIMTP}
 };
 
+static int win=0;
+
 static int np;
 static float eject_r,dt,maxage,eject_vy,eject_vl;
 static short shadows;
@@ -683,14 +688,16 @@ int main(int ac,char **av)
     ys=atoi(av[3]);
   }
 
-  glutInitDisplayMode(GLUT_RGB|GLUT_DEPTH|GLUT_DOUBLE);
-  glutInitWindowSize(640,480);
+  glutInitWindowPosition(0,0);
+  glutInitWindowSize(WIDTH,HEIGHT);
+  glutInit(&ac,av);
 
-  if (glutCreateWindow("Fire") == GL_FALSE) {
-    printf("Error opening a window.\n");
+  glutInitDisplayMode(GLUT_RGB|GLUT_DEPTH|GLUT_DOUBLE);
+
+  if(!(win=glutCreateWindow("Fire"))) {
+    fprintf(stderr,"Error opening a window.\n");
     exit(-1);
   }
-
   
   reshape(xs,ys);
 
